framework/verb
Types
Values
pub fn compound(
first: fn(io.Context) -> io.Promise(intermediate),
then: fn(io.Context, intermediate) -> io.Promise(value),
) -> Verb(value)
Stage two database operations in one transaction. The second operation is used by reorder so a unique order column can be cleared into temporary values before the requested values are assigned.
pub fn stage(
verb: Verb(value),
context: io.Context,
) -> io.Promise(value)
pub fn staged(
stage: fn(io.Context) -> io.Promise(value),
) -> Verb(value)
Generated adapters may stage SQL. They never execute it here.